@@ -4,16 +4,16 @@
 # FILE    : tool
 # PROJECT : funfunc
 # IDE     : PyCharm
-from datetime import datetime as _datetime
-import os
-from functools import wraps
-import time
-from typing import List as _List
+import datetime
+import functools
 import logging
+import os
+import time
+import typing
 
 
 def get_current_str_time() -> str:
-    now_time = _datetime.now()
+    now_time = datetime.datetime.now()
     str_time = now_time.strftime('%Y年%m月%d日星期%w %H时%M分%S秒')
     return str_time
 
@@ -28,7 +28,7 @@ def download_file(url, save_path):
 
 
 def time_it(method):
-    @wraps(method)
+    @functools.wraps(method)
     def waapper(*args, **kwargs):
         start = time.time()
         result = method(*args, **kwargs)
@@ -40,7 +40,7 @@ def time_it(method):
     return waapper
 
 
-def quick_sort(arr: _List[int]) -> _List[int]:
+def quick_sort(arr: typing.List[int]) -> typing.List[int]:
     if len(arr) < 2:
         return arr
     temp = arr[0]
@@ -82,11 +82,9 @@ def get_host_ip():
 
 def time_to_timestamp(date):
     """时间转化为时间戳"""
-    return _datetime.strptime(date, "%Y-%m-%d %H:%M:%S").timestamp()
+    return datetime.datetime.strptime(date, "%Y-%m-%d %H:%M:%S").timestamp()
 
 
 def second_to_strtime(second: int):
     """秒转化为分秒"""
     return time.strftime("%M:%S", time.gmtime(second))
-
-
