@@ -4,11 +4,11 @@
 # FILE    : tornado
 # PROJECT : funfunc
 # IDE     : PyCharm
-from tornado import web as _web
+import tornado
 
 
 # 解决tornado-vue 跨域问题
-class BaseTornadoWebHandler(_web.RequestHandler):
+class BaseTornadoWebHandler(tornado.web.RequestHandler):
     def data_received(self, chunk):
         pass
 
